# Project Harvest

- [/] turn compost heap
- [ ] plan raised bed layout
- [ ] _buy copper tape for slugs_
- [ ] **order squash seeds**

## **Spring planting**

- [ ] sow tomato seeds indoors
- [ ] direct sow carrots

## Hardening off

- [X] move seedlings to cold frame

## Autumn

- [#] enter giant marrow contest (too late)
